@@ -24,6 +24,7 @@ API_PATH = {
     "holiday_create":                   "/users/holidays",
     "holiday_update":                   "/users/holidays/{id}",
     "holiday_delete":                   "/users/holidays/{id}",
+    "hourly_rate_get":                  "/hourly_rates",
     "invoice_getlist":                  "/invoices",
     "invoice_get":                      "/invoices/{id}",
     "invoice_locked":                   "/invoices/locked",
@@ -31,6 +32,7 @@ API_PATH = {
     "invoice_timesheet":                "/invoices/{id}/timesheet.pdf",
     "invoice_update_status":            "/invoices/{id}/update_status",
     "invoice_create":                   "/invoices",
+    "invoice_send_email":               "/invoices/{id}/send_email",
     "invoice_payment_getlist":          "/invoices/payments",
     "invoice_payment_get":              "/invoices/payments/{id}",
     "invoice_payment_create":           "/invoices/payments",
