@@ -3,12 +3,14 @@ from moco_wrapper.const import API_PATH
 
 from enum import Enum
 
+
 class CommentTargetType(str, Enum):
     """
-    Enumeration for allowed values used that can be supplied for the ``commentable_type`` argument in :meth:`.Comment.create`, :meth:`.Comment.create_bulk` and :meth:`.Comment.getlist`
+    Enumeration for allowed values used that can be supplied for the ``commentable_type`` argument in
+    :meth:`.Comment.create`, :meth:`.Comment.create_bulk` and :meth:`.Comment.getlist`
 
     .. code-block:: python
-    
+
         from moco_wrapper import Moco
         from moco_wrapper.models.comment import CommentTargetType
 
@@ -28,17 +30,19 @@ class CommentTargetType(str, Enum):
     INVOICE = "Invoice"
     CONTACT = "Contact"
 
+
 class Comment(MWRAPBase):
     """
     Class for handling comments.
 
-    Comments can be created for a multitude of objects. So when creating comments one must specify which type of object they mean (see :class:`.CommentTargetType`)
-    
+    Comments can be created for a multitude of objects. So when creating comments one must specify which type of object
+    they target (see :class:`.CommentTargetType`)
+
     Example Usage:
 
     .. code-block:: python
-    
-    
+
+
         m = Moco()
         project_id = 22
         comment_create = m.Comment.create(
@@ -61,11 +65,12 @@ class Comment(MWRAPBase):
         commentable_id: int,
         commentable_type: CommentTargetType,
         text: str
-        ):
+    ):
         """
-        Create a single comment. 
+        Create a single comment.
 
-        :param commentable_id: Id of the object to create the comment of (i.e the project id of the project we want to comment on)
+        :param commentable_id: Id of the object to create the comment of (i.e the project id of the project we want to
+            comment on)
         :param commentable_type: Type of object to create the comment for.
         :param text: Comment text
 
@@ -74,10 +79,11 @@ class Comment(MWRAPBase):
         :type text: str
 
         :returns: The created comment
+        :rtype: :class:`moco_wrapper.util.response.JsonResponse`
         """
         data = {
             "commentable_id": commentable_id,
-            "commentable_type" : commentable_type,
+            "commentable_type": commentable_type,
             "text": text
         }
 
@@ -88,24 +94,25 @@ class Comment(MWRAPBase):
         commentable_ids: list,
         commentable_type: CommentTargetType,
         text: str
-        ):
+    ):
         """
         Create a comment for multiple target objects.
 
-        :param commentable_ids: ids of the objects we want to comment under ie. [123, 124, 125]
-        :param commentable_type: type of object to create the comment for. For allowed values see :class:`.CommentTargetType`.
-        :param text: comment text
+        :param commentable_ids: Ids of the objects we want to comment under ie. [123, 124, 125]
+        :param commentable_type: Type of object to create the comment for.
+        :param text: Comment text
 
         :type commentable_ids: list
         :type commentable_type: :class:`.CommentTargetType`, str
         :type text: str
 
         :returns: List of created comments.
+        :rtype: :class:`moco_wrapper.util.response.ListingResponse`
         """
         data = {
-            "commentable_ids" : commentable_ids,
+            "commentable_ids": commentable_ids,
             "commentable_type": commentable_type,
-            "text" : text
+            "text": text
         }
 
         return self._moco.post(API_PATH["comment_create_bulk"], data=data)
@@ -114,7 +121,7 @@ class Comment(MWRAPBase):
         self,
         comment_id: int,
         text: str
-        ):
+    ):
         """
         Update a comment.
 
@@ -125,9 +132,10 @@ class Comment(MWRAPBase):
         :type text: str
 
         :returns: The created comment
+        :rtype: :class:`moco_wrapper.util.response.JsonResponse`
         """
         data = {
-            "text" : text,  
+            "text": text,
         }
 
         return self._moco.put(API_PATH["comment_update"].format(id=comment_id), data=data)
@@ -135,7 +143,7 @@ class Comment(MWRAPBase):
     def delete(
         self,
         comment_id: int,
-        ):
+    ):
         """
         Delete a comment.
 
@@ -144,6 +152,7 @@ class Comment(MWRAPBase):
         :type comment_id: int
 
         :returns: Empty response on success
+        :rtype: :class:`moco_wrapper.util.response.EmptyResponse`
         """
 
         return self._moco.delete(API_PATH["comment_delete"].format(id=comment_id))
@@ -151,7 +160,7 @@ class Comment(MWRAPBase):
     def get(
         self,
         comment_id: int
-        ):
+    ):
         """
         Retrieve a single comment.
 
@@ -160,6 +169,7 @@ class Comment(MWRAPBase):
         :type comment_id: int
 
         :returns: Single comment
+        :rtype: :class:`moco_wrapper.util.response.JsonResponse`
         """
         return self._moco.get(API_PATH["comment_get"].format(id=comment_id))
 
@@ -172,17 +182,17 @@ class Comment(MWRAPBase):
         sort_by: str = None,
         sort_order: str = 'asc',
         page: int = 1
-        ):
+    ):
         """
         Retrieve a list of comments.
 
-        :param commentable_type: Type of object the comment(s) belong to
-        :param commentable_id: Id of the object the comment belongs to
-        :param user_id: User id of the creator
-        :param manual: If the comment was user-created of generated
-        :param sort_by: Field to sort the results by
-        :param sort_order: asc or desc
-        :param page: Page number (default 1)
+        :param commentable_type: Type of object the comment(s) belong to (default ``None``)
+        :param commentable_id: Id of the object the comment belongs to (default ``None``)
+        :param user_id: User id of the creator (default ``None``)
+        :param manual: If the comment was user-created of generated (default ``None``)
+        :param sort_by: Field to sort the results by (default ``None``)
+        :param sort_order: asc or desc (default ``"asc"``)
+        :param page: Page number (default ``1``)
 
         :type commentable_type: :class:`.CommentTargetType`, str
         :type commentable_id: int
@@ -193,6 +203,7 @@ class Comment(MWRAPBase):
         :type page: int
 
         :returns: list of comments
+        :rtype: :class:`moco_wrapper.util.response.ListingResponse`
         """
         params = {}
         for key, value in (
