@@ -60,7 +60,7 @@ class InvoiceChangeAddress(str, Enum):
 
 class Invoice(MWRAPBase):
     """
-    Models for handling invoices.
+    Model for handling invoices.
     """
 
     def __init__(self, moco):
@@ -369,3 +369,70 @@ class Invoice(MWRAPBase):
                 data[key] = value
 
         return self._moco.post(API_PATH["invoice_create"], data=data)
+
+    def send_email(
+        self,
+        invoice_id: int,
+        emails_to: str,
+        subject: str,
+        text: str,
+        emails_cc: str = None,
+        emails_bcc: str = None
+    ):
+        """
+        Send an invoice by mail
+
+        :param invoice_id: Id of the invoice to send
+        :param emails_to: Target email address (or a list of multiple email addresses)
+        :param subject: Email subject
+        :param text: Email text
+        :param emails_cc: Email address for cc (or a list of multiple email addresses) (default ``None``)
+        :param emails_bcc: Email address for bcc (or a list of multiple email addresses) (default ``None``)
+
+        :type invoice_id: int
+        :type emails_to: str, list
+        :type subject: str
+        :type text: str
+        :type emails_cc: str, list
+        :type emails_bcc: str, list
+
+        .. note::
+
+            If you want to send an email to the default recipient configured in the project or customer,
+            set ``emails_to`` and ``emails_cc`` To ``None``.
+
+        """
+        if emails_to is None:
+            emails_to = []
+
+        if emails_cc is None:
+            emails_cc = []
+
+        if emails_bcc is None:
+            emails_bcc = []
+
+        data = {
+            "subject": subject,
+            "text": text
+        }
+
+        if isinstance(emails_to, list):
+            data["emails_to"] = ";".join(emails_to)
+        else:
+            data["emails_to"] = emails_to
+
+        for key, value in (
+            ("emails_cc", emails_cc),
+            ("emails_bcc", emails_bcc)
+        ):
+
+            if value is not None:
+                if key in ["emails_cc", "emails_bcc"] and isinstance(value, list) and len(value) > 0:
+                    data[key] = ";".join(value)
+                elif isinstance(value, list) and len(value) == 0:
+                    # skip lists with 0 elements
+                    pass
+                else:
+                    data[key] = value
+
+        return self._moco.post(API_PATH["invoice_send_email"].format(id=invoice_id), data=data)
