@@ -17,7 +17,7 @@ from .unit import Unit
 from .offer import Offer
 from .deal import Deal
 from .contact import Contact
-from .invoice import Invoice
+from .invoice import Invoice, InvoiceEmail
 from .invoice_payment import InvoicePayment
 from .deal_category import DealCategory
 from .company import Company
@@ -29,3 +29,5 @@ from .purchase_category import PurchaseCategory
 from .purchase import Purchase
 
 from .planning_entry import PlanningEntry
+
+from .hourly_rate import HourlyRate
