@@ -49,9 +49,14 @@ class Project(MWRAPBase):
         currency: str,
         leader_id: int,
         customer_id: int,
+        deal_id: int = None,
         finish_date: datetime.date = None,
         identifier: str = None,
         billing_address: str = None,
+        billing_email_to: str = None,
+        billing_email_cc: str = None,
+        billing_notes: str = None,
+        setting_include_time_report: bool = None,
         billing_variant: ProjectBillingVariant = None,
         hourly_rate: float = None,
         budget: float = None,
@@ -67,9 +72,14 @@ class Project(MWRAPBase):
         :param currency: Currency used by the project (e.g. EUR)
         :param leader_id: User id of the project leader
         :param customer_id: Company id of the customer
+        :param deal_id: Deal id the the project originated from
         :param finish_date: Finish date (default ``None``)
         :param identifier: Project Identifier (default ``None``)
         :param billing_address: Billing address the invoices go to (default ``None``)
+        :param billing_email_to: Email address to send billing email to (default ``None``)
+        :param billing_email_cc: Email address to cc in billing emails (default ``None``)
+        :param billing_notes: Billing notes (default ``None``)
+        :param setting_include_time_report: Include time report in billing emails (default ``None``)
         :param billing_variant: Billing variant used (default ``None``)
         :param hourly_rate: Hourly rate that will get billed (default ``None``)
         :param budget: Budget for the project (default ``None``)
@@ -82,9 +92,14 @@ class Project(MWRAPBase):
         :type currency: str
         :type leader_id: int
         :type customer_id: int
+        :type deal_id: int
         :type finish_date: datetime.date, str
         :type identifier: str
         :type billing_address: str
+        :type billing_email_to: str
+        :type billing_email_cc: str
+        :type billing_notes: str
+        :type setting_include_time_report: bool
         :type billing_variant: :class:`.ProjectBillingVariant`, str
         :type hourly_rate: float
         :type budget: float
@@ -113,9 +128,14 @@ class Project(MWRAPBase):
             raise ValueError("When you create a fixed price project, the project budget must be set")
 
         for key, value in (
+            ("deal_id", deal_id),
             ("finish_date", finish_date),
             ("identifier", identifier),
             ("billing_address", billing_address),
+            ("billing_email_to", billing_email_to),
+            ("billing_email_cc", billing_email_cc),
+            ("billing_notes", billing_notes),
+            ("setting_include_time_report", setting_include_time_report),
             ("billing_variant", billing_variant),
             ("hourly_rate", hourly_rate),
             ("budget", budget),
@@ -138,9 +158,14 @@ class Project(MWRAPBase):
         name: str = None,
         leader_id: int = None,
         customer_id: int = None,
+        deal_id: int = None,
         finish_date: datetime.date = None,
         identifier: str = None,
         billing_address: str = None,
+        billing_email_to: str = None,
+        billing_email_cc: str = None,
+        billing_notes: str = None,
+        setting_include_time_report: bool = None,
         billing_variant: ProjectBillingVariant = None,
         hourly_rate: float = None,
         budget: float = None,
@@ -155,9 +180,14 @@ class Project(MWRAPBase):
         :param name: Name of the project (default ``None``)
         :param leader_id: User id of the project leader (default ``None``)
         :param customer_id: Company id of the customer (default ``None``)
+        :param deal_id: Deal id of the project (default ``None``)
         :param finish_date: Finish date (default ``None``)
         :param identifier: Project Identifier (default ``None``)
         :param billing_address: Address the invoices go to (default ``None``)
+        :param billing_email_to: Email address to send billing emails to (default ``None``)
+        :param billing_email_cc: Email address to cc in billing emails (default ``None``)
+        :param billing_notes: Billing notes
+        :param setting_include_time_report: Include time reports in billing emails
         :param billing_variant: Billing variant used (default ``None``)
         :param hourly_rate: Hourly rate that will get billed (default ``None``)
         :param budget: Budget for the project (default ``None``)
@@ -169,9 +199,14 @@ class Project(MWRAPBase):
         :type name: str
         :type leader_id: int
         :type customer_id: int
+        :type deal_id: int
         :type finish_date: datetime.date, str
         :type identifier: str
         :type billing_address: str
+        :type billing_email_to: str
+        :type billing_email_cc: str
+        :type billing_notes: str
+        :type setting_include_time_report: bool
         :type billing_variant: :class:`.ProjectBillingVariant`, str
         :type hourly_rate: float
         :type budget: float
@@ -188,9 +223,14 @@ class Project(MWRAPBase):
             ("name", name),
             ("leader_id", leader_id),
             ("customer_id", customer_id),
+            ("deal_id", deal_id),
             ("finish_date", finish_date),
             ("identifier", identifier),
             ("billing_address", billing_address),
+            ("billing_email_to", billing_email_to),
+            ("billing_email_cc", billing_email_cc),
+            ("billing_notes", billing_notes),
+            ("setting_include_time_report", setting_include_time_report),
             ("billing_variant", billing_variant),
             ("hourly_rate", hourly_rate),
             ("budget", budget),
