@@ -5,6 +5,7 @@ from datetime import date
 
 from .. import IntegrationTest
 
+
 class TestProject(IntegrationTest):
     def get_unit(self):
         with self.recorder.use_cassette("TestProject.get_unit"):
@@ -21,24 +22,43 @@ class TestProject(IntegrationTest):
 
         with self.recorder.use_cassette("TestProject.get_other_user"):
             user_create = self.moco.User.create(
-                "dummy user",
-                "testing contracts",
-                "{}@mycompany.com".format(self.id_generator()),
-                self.id_generator(),
-                unit.id,
+                firstname="dummy user",
+                lastname="testing contracts",
+                email="{}@example.org".format(self.id_generator()),
+                password=self.id_generator(),
+                unit_id=unit.id,
             )
 
             return user_create.data
-    
+
     def get_customer(self):
         with self.recorder.use_cassette("TestProject.get_customer"):
             customer_create = self.moco.Company.create(
-                "TestProject",
+                name="TestProject",
                 company_type="customer"
             )
 
             return customer_create.data
 
+    def get_deal_category(self):
+        with self.recorder.use_cassette("TestProject.get_deal_category"):
+            deal_category = self.moco.DealCategory.getlist().items[0]
+            return deal_category
+
+    def get_deal(self):
+        category = self.get_deal_category()
+        user = self.get_user()
+
+        with self.recorder.use_cassette("TestProject.get_deal"):
+            deal_create = self.moco.Deal.create(
+                name="dummy deal",
+                currency="EUR",
+                money=100,
+                reminder_date=date(2021, 1, 1),
+                user_id=user.id,
+                deal_category_id=category.id
+            )
+            return deal_create.data
 
     def test_create(self):
         user = self.get_user()
@@ -48,12 +68,12 @@ class TestProject(IntegrationTest):
             name = "test project create"
             currency = "EUR"
             finish_date = date(2021, 1, 1)
-            
+
             project_create = self.moco.Project.create(
-                name,
-                currency,
-                user.id,
-                customer.id,
+                name=name,
+                currency=currency,
+                leader_id=user.id,
+                customer_id=customer.id,
                 finish_date=finish_date
             )
 
@@ -67,6 +87,29 @@ class TestProject(IntegrationTest):
             assert project_create.data.leader.id == user.id
             assert project_create.data.customer.id == customer.id
 
+    def test_create_with_deal(self):
+        user = self.get_user()
+        customer = self.get_customer()
+        deal = self.get_deal()
+
+        with self.recorder.use_cassette("TestProject.test_create_with_deal"):
+            name = "test project create with deal"
+            currency = "EUR"
+
+            project_create = self.moco.Project.create(
+                name=name,
+                currency=currency,
+                leader_id=user.id,
+                customer_id=customer.id,
+                deal_id=deal.id
+            )
+
+            assert project_create.data.name == name
+            assert project_create.data.currency == currency
+            assert project_create.data.leader.id == user.id
+            assert project_create.data.customer.id == customer.id
+            assert project_create.data.deal.id == deal.id
+
     def test_create_full(self):
         user = self.get_user()
         customer = self.get_customer()
@@ -76,19 +119,27 @@ class TestProject(IntegrationTest):
             currency = "EUR"
             finish_date = date(2021, 1, 1)
             billing_address = "general street 22"
+            billing_email_to = "billing@example.org"
+            billing_email_cc = "billing-cc@example.org"
+            billing_notes = "billing notes text"
+            setting_include_time_report = True
             billing_variant = ProjectBillingVariant.PROJECT
             hourly_rate = 12.5
             budget = 100
             labels = ["low risk", "low income"]
             info = "general information"
-            
+
             project_create = self.moco.Project.create(
-                name,
-                currency,
-                user.id,
-                customer.id,
+                name=name,
+                currency=currency,
+                leader_id=user.id,
+                customer_id=customer.id,
                 finish_date=finish_date,
                 billing_address=billing_address,
+                billing_email_to=billing_email_to,
+                billing_email_cc=billing_email_cc,
+                billing_notes=billing_notes,
+                setting_include_time_report=setting_include_time_report,
                 billing_variant=billing_variant,
                 hourly_rate=hourly_rate,
                 budget=budget,
@@ -106,6 +157,10 @@ class TestProject(IntegrationTest):
             assert project_create.data.leader.id == user.id
             assert project_create.data.customer.id == customer.id
             assert project_create.data.billing_address == billing_address
+            assert project_create.data.billing_email_to == billing_email_to
+            assert project_create.data.billing_email_cc == billing_email_cc
+            assert project_create.data.billing_notes == billing_notes
+            assert project_create.data.setting_include_time_report == setting_include_time_report
             assert project_create.data.billing_variant == billing_variant
             assert project_create.data.hourly_rate == hourly_rate
             assert project_create.data.budget == budget
@@ -126,12 +181,12 @@ class TestProject(IntegrationTest):
             budget = 100
             labels = ["low risk", "low income"]
             info = "general information"
-            
+
             project_create = self.moco.Project.create(
-                name,
-                currency,
-                user.id,
-                customer.id,
+                name=name,
+                currency=currency,
+                leader_id=user.id,
+                customer_id=customer.id,
                 finish_date=finish_date,
                 billing_address=billing_address,
                 billing_variant=billing_variant,
@@ -170,6 +225,10 @@ class TestProject(IntegrationTest):
             currency = "EUR"
             finish_date = date(2021, 1, 1)
             billing_address = "general street 22"
+            billing_email_to = "billing-update@example.org"
+            billing_email_cc = "billing-cc-update@example.org"
+            billing_notes = "billings notes update text"
+            setting_include_time_report = False
             billing_variant = ProjectBillingVariant.PROJECT
             hourly_rate = 12.5
             budget = 100
@@ -177,20 +236,24 @@ class TestProject(IntegrationTest):
             info = "general information"
 
             project_create = self.moco.Project.create(
-                "dummy project, test update",
-                "EUR",
-                user.id,
-                customer.id,
-                finish_date = date(2020, 1, 1),
+                name="dummy project, test update",
+                currency="EUR",
+                leader_id=user.id,
+                customer_id=customer.id,
+                finish_date=date(2020, 1, 1),
             )
-            
+
             project_update = self.moco.Project.update(
-                project_create.data.id,
+                project_id=project_create.data.id,
                 name=name,
                 finish_date=finish_date,
                 leader_id=user.id,
                 customer_id=customer.id,
                 billing_address=billing_address,
+                billing_email_to=billing_email_to,
+                billing_email_cc=billing_email_cc,
+                billing_notes=billing_notes,
+                setting_include_time_report=setting_include_time_report,
                 billing_variant=billing_variant,
                 hourly_rate=hourly_rate,
                 budget=budget,
@@ -210,6 +273,10 @@ class TestProject(IntegrationTest):
             assert project_update.data.leader.id == user.id
             assert project_update.data.customer.id == customer.id
             assert project_update.data.billing_address == billing_address
+            assert project_update.data.billing_email_to == billing_email_to
+            assert project_update.data.billing_email_cc == billing_email_cc
+            assert project_update.data.billing_notes == billing_notes
+            assert project_update.data.setting_include_time_report == setting_include_time_report
             assert project_update.data.billing_variant == billing_variant
             assert project_update.data.hourly_rate == hourly_rate
             assert project_update.data.budget == budget
@@ -224,16 +291,16 @@ class TestProject(IntegrationTest):
 
         with self.recorder.use_cassette("TestProject.test_create_contract"):
             project_create = self.moco.Project.create(
-                "dummy project, test contracts",
-                "EUR",
-                user.id,
-                customer.id,
+                name="dummy project, test contracts",
+                currency="EUR",
+                leader_id=user.id,
+                customer_id=customer.id,
                 finish_date=date(2020, 1, 1),
             )
 
             contract_create = self.moco.ProjectContract.create(
-                project_create.data.id,
-                other_user.id
+                project_id=project_create.data.id,
+                user_id=other_user.id
             )
 
             project_get = self.moco.Project.get(project_create.data.id)
@@ -250,22 +317,20 @@ class TestProject(IntegrationTest):
 
     def test_create_task(self):
         user = self.get_user()
-        other_user = self.get_other_user()
-
         customer = self.get_customer()
 
         with self.recorder.use_cassette("TestProject.test_create_task"):
             project_create = self.moco.Project.create(
-                "dummy project, test tasks",
-                "EUR",
-                user.id,
-                customer.id,
+                name="dummy project, test tasks",
+                currency="EUR",
+                leader_id=user.id,
+                customer_id=customer.id,
                 finish_date=date(2020, 1, 1),
             )
 
             task_create = self.moco.ProjectTask.create(
-                project_create.data.id,
-                "dummy task, test project with task",
+                project_id=project_create.data.id,
+                name="dummy task, test project with task",
             )
 
             project_get = self.moco.Project.get(project_create.data.id)
@@ -297,7 +362,7 @@ class TestProject(IntegrationTest):
             )
 
             assert project_list.response.status_code == 200
-            
+
             assert isinstance(project_list, ListingResponse)
 
             assert project_list.current_page == 1
@@ -326,11 +391,11 @@ class TestProject(IntegrationTest):
 
         with self.recorder.use_cassette("TestProject.test_archive"):
             project_create = self.moco.Project.create(
-                "dummy project, test archive",
-                "EUR",
-                user.id,
-                customer.id,
-                finish_date = date(2020, 1, 1),
+                name="dummy project, test archive",
+                currency="EUR",
+                leader_id=user.id,
+                customer_id=customer.id,
+                finish_date=date(2020, 1, 1),
             )
 
             project_archive = self.moco.Project.archive(project_create.data.id)
@@ -349,11 +414,11 @@ class TestProject(IntegrationTest):
 
         with self.recorder.use_cassette("TestProject.test_unarchive"):
             project_create = self.moco.Project.create(
-                "dummy project, test unarchive",
-                "EUR",
-                user.id,
-                customer.id,
-                finish_date = date(2020, 1, 1),
+                name="dummy project, test unarchive",
+                currency="EUR",
+                leader_id=user.id,
+                customer_id=customer.id,
+                finish_date=date(2020, 1, 1),
             )
 
             project_archive = self.moco.Project.archive(project_create.data.id)
@@ -374,13 +439,13 @@ class TestProject(IntegrationTest):
 
         with self.recorder.use_cassette("TestProject.test_report"):
             project_create = self.moco.Project.create(
-                "dummy project, test report",
-                "EUR",
-                user.id,
-                customer.id,
-                finish_date = date(2020, 1, 1),
+                name="dummy project, test report",
+                currency="EUR",
+                leader_id=user.id,
+                customer_id=customer.id,
+                finish_date=date(2020, 1, 1),
             )
-            
+
             project_report = self.moco.Project.report(project_create.data.id)
 
             assert project_create.response.status_code == 200
@@ -396,12 +461,12 @@ class TestProject(IntegrationTest):
         with self.recorder.use_cassette("TestProject.test_create_without_finish_date"):
             name = "test project create"
             currency = "EUR"
-            
+
             project_create = self.moco.Project.create(
-                name,
-                currency,
-                user.id,
-                customer.id,
+                name=name,
+                currency=currency,
+                leader_id=user.id,
+                customer_id=customer.id,
             )
 
             assert project_create.response.status_code == 200
@@ -423,12 +488,12 @@ class TestProject(IntegrationTest):
             currency = "EUR"
             budget = 200
             fixed_price = True
-            
+
             project_create = self.moco.Project.create(
-                name,
-                currency,
-                user.id,
-                customer.id,
+                name=name,
+                currency=currency,
+                leader_id=user.id,
+                customer_id=customer.id,
                 fixed_price=fixed_price,
                 budget=200
             )
@@ -444,4 +509,3 @@ class TestProject(IntegrationTest):
             assert project_create.data.customer.id == customer.id
             assert project_create.data.budget == budget
             assert project_create.data.fixed_price == fixed_price
-            
\ No newline at end of file
