@@ -1,6 +1,7 @@
 import pytest
 from .. import UnitTest
 
+
 class TestProject(UnitTest):
 
     def test_create(self):
@@ -9,18 +10,42 @@ class TestProject(UnitTest):
         finish_date = "2019-05-15"
         leader_id = 4123
         customer_id = 4
+        deal_id = 834
         identifier = "PROJ-4"
         billing_address = "this is the billing address"
+        billing_email_to = "billing-to@example.org"
+        billing_email_cc = "billing-cc@example.org"
+        billing_notes = "billing notes text"
+        setting_include_time_report = True
         billing_variant = "project"
         hourly_rate = 124
         budget = 120000
         labels = ["this", "is", "my", "board"]
         custom_properties = {
-            "boards" : 14
+            "boards": 14
         }
         info = "more information about boards"
 
-        response = self.moco.Project.create(name, currency, leader_id, customer_id,  finish_date=finish_date, identifier=identifier, billing_address=billing_address, billing_variant=billing_variant, hourly_rate=hourly_rate, budget=budget, labels=labels, custom_properties=custom_properties, info=info)
+        response = self.moco.Project.create(
+            name=name,
+            currency=currency,
+            leader_id=leader_id,
+            customer_id=customer_id,
+            deal_id=deal_id,
+            finish_date=finish_date,
+            identifier=identifier,
+            billing_address=billing_address,
+            billing_email_to=billing_email_to,
+            billing_email_cc=billing_email_cc,
+            billing_notes=billing_notes,
+            setting_include_time_report=setting_include_time_report,
+            billing_variant=billing_variant,
+            hourly_rate=hourly_rate,
+            budget=budget,
+            labels=labels,
+            custom_properties=custom_properties,
+            info=info
+        )
         data = response["data"]
 
         assert data["name"] == name
@@ -28,13 +53,18 @@ class TestProject(UnitTest):
         assert data["finish_date"] == finish_date
         assert data["leader_id"] == leader_id
         assert data["customer_id"] == customer_id
+        assert data["deal_id"] == deal_id
         assert data["billing_address"] == billing_address
+        assert data["billing_email_to"] == billing_email_to
+        assert data["billing_email_cc"] == billing_email_cc
+        assert data["billing_notes"] == billing_notes
+        assert data["setting_include_time_report"] == setting_include_time_report
         assert data["billing_variant"] == billing_variant
         assert data["hourly_rate"] == hourly_rate
         assert data["labels"] == labels
         assert data["custom_properties"] == custom_properties
         assert data["info"] == info
-        
+
         assert response["method"] == "POST"
 
     def test_update(self):
@@ -43,31 +73,60 @@ class TestProject(UnitTest):
         finish_date = "2019-05-15"
         leader_id = 4123
         customer_id = 4
+        deal_id = 231
         identifier = "PROJ-4"
         billing_address = "this is the billing address"
+        billing_email_to = "billing-to-update@example.org"
+        billing_email_cc = "billing-cc-update@example.org"
+        billing_notes = "billing notes update text"
+        setting_include_time_report = True
         billing_variant = "project"
         hourly_rate = 124
         budget = 120000
         labels = ["this", "is", "my", "board"]
         custom_properties = {
-            "boards" : 14
+            "boards": 14
         }
         info = "more information about boards"
 
-        response = self.moco.Project.update(project_id, name=name, finish_date=finish_date, leader_id=leader_id, customer_id=customer_id, identifier=identifier, billing_address=billing_address, billing_variant=billing_variant, hourly_rate=hourly_rate, budget=budget, labels=labels, custom_properties=custom_properties, info=info)
+        response = self.moco.Project.update(
+            project_id=project_id,
+            name=name,
+            finish_date=finish_date,
+            leader_id=leader_id,
+            customer_id=customer_id,
+            deal_id=deal_id,
+            identifier=identifier,
+            billing_address=billing_address,
+            billing_email_to=billing_email_to,
+            billing_email_cc=billing_email_cc,
+            billing_notes=billing_notes,
+            setting_include_time_report=setting_include_time_report,
+            billing_variant=billing_variant,
+            hourly_rate=hourly_rate,
+            budget=budget,
+            labels=labels,
+            custom_properties=custom_properties,
+            info=info
+        )
         data = response["data"]
 
         assert data["name"] == name
         assert data["finish_date"] == finish_date
         assert data["leader_id"] == leader_id
         assert data["customer_id"] == customer_id
+        assert data["deal_id"] == deal_id
         assert data["billing_address"] == billing_address
+        assert data["billing_email_to"] == billing_email_to
+        assert data["billing_email_cc"] == billing_email_cc
+        assert data["billing_notes"] == billing_notes
+        assert data["setting_include_time_report"] == setting_include_time_report
         assert data["billing_variant"] == billing_variant
         assert data["hourly_rate"] == hourly_rate
         assert data["labels"] == labels
         assert data["custom_properties"] == custom_properties
         assert data["info"] == info
-        
+
         assert response["method"] == "PUT"
 
     def test_get(self):
@@ -89,7 +148,19 @@ class TestProject(UnitTest):
         tags = ["these", "are", "my", "tags"]
         identifier = "PROJ-IAM-SEARCHING"
 
-        response = self.moco.Project.getlist(include_archived=include_archived, include_company=include_company, leader_id=leader_id, company_id=company_id, created_from=created_from, created_to=created_to, updated_from=updated_from, updated_to=updated_to, tags=tags, identifier=identifier)
+        response = self.moco.Project.getlist(
+            include_archived=include_archived,
+            include_company=include_company,
+            leader_id=leader_id,
+            company_id=company_id,
+            created_from=created_from,
+            created_to=created_to,
+            updated_from=updated_from,
+            updated_to=updated_to,
+            tags=tags,
+            identifier=identifier
+        )
+
         params = response["params"]
 
         assert params["include_archived"] == include_archived
@@ -132,7 +203,6 @@ class TestProject(UnitTest):
         response = self.moco.Project.getlist(page=page_overwrite)
         assert response["params"]["page"] == page_overwrite
 
-
     def test_assigned(self):
         active = False
 
@@ -167,7 +237,6 @@ class TestProject(UnitTest):
         response = self.moco.Project.assigned(page=page_overwrite)
         assert response["params"]["page"] == page_overwrite
 
-
     def test_archive(self):
         project_id = 123
 
