@@ -1,23 +1,27 @@
-import pytest   
+import pytest
 
 from .. import UnitTest
 
+
 class TestSchedule(UnitTest):
     def test_getlist(self):
         from_date = '2019-10-10'
         to_date = '2015-05-05'
         user_id = 4
-        project_id = 23
-        absence_code  = 342
+        absence_code = 342
 
-        response = self.moco.Schedule.getlist(from_date=from_date, to_date=to_date, user_id=user_id, project_id=project_id, absence_code =absence_code )
+        response = self.moco.Schedule.getlist(
+            from_date=from_date,
+            to_date=to_date,
+            user_id=user_id,
+            absence_code=absence_code
+        )
         params = response["params"]
 
         assert params["from"] == from_date
         assert params["to"] == to_date
         assert params["user_id"] == user_id
-        assert params["project_id"] == project_id
-        assert params["absence_code "] == absence_code 
+        assert params["absence_code "] == absence_code
 
         assert response["method"] == "GET"
 
@@ -55,29 +59,7 @@ class TestSchedule(UnitTest):
 
         assert response["method"] == "GET"
 
-    def test_create_with_project(self):
-        date = "2019-10-10"
-        project_id = 4
-        user_id = 234
-        am = True
-        pm = True
-        comment = "this is the comment comment"
-        overwrite = True
-
-        response = self.moco.Schedule.create(date, project_id=project_id, user_id=user_id, am=am, pm=pm, comment=comment, overwrite=overwrite)
-        data = response["data"]
-
-        assert data["date"] == date
-        assert data["project_id"] == project_id
-        assert data["user_id"] == user_id
-        assert data["am"] == am
-        assert data["pm"] == pm
-        assert data["comment"] == comment
-        assert data["overwrite"] == overwrite
-
-        assert response["method"] == "POST"
-
-    def test_create_with_absence(self):
+    def test_create(self):
         date = "2019-10-10"
         absence_code = 5
         user_id = 234
@@ -86,7 +68,15 @@ class TestSchedule(UnitTest):
         comment = "this is the comment comment"
         overwrite = True
 
-        response = self.moco.Schedule.create(date, absence_code=absence_code, user_id=user_id, am=am, pm=pm, comment=comment, overwrite=overwrite)
+        response = self.moco.Schedule.create(
+            schedule_date=date,
+            absence_code=absence_code,
+            user_id=user_id,
+            am=am,
+            pm=pm,
+            comment=comment,
+            overwrite=overwrite
+        )
         data = response["data"]
 
         assert data["date"] == date
@@ -99,7 +89,7 @@ class TestSchedule(UnitTest):
 
         assert response["method"] == "POST"
 
-    def test_update_with_absence(self):
+    def test_update(self):
         schedule_id = 2434
         absence_code = 5
         am = True
@@ -107,7 +97,14 @@ class TestSchedule(UnitTest):
         comment = "this is the comment comment"
         overwrite = True
 
-        response = self.moco.Schedule.update(schedule_id, absence_code=absence_code, am=am, pm=pm, comment=comment, overwrite=overwrite)
+        response = self.moco.Schedule.update(
+            schedule_id=schedule_id,
+            absence_code=absence_code,
+            am=am,
+            pm=pm,
+            comment=comment,
+            overwrite=overwrite
+        )
         data = response["data"]
 
         assert data["absence_code"] == absence_code
@@ -119,29 +116,9 @@ class TestSchedule(UnitTest):
         assert response["method"] == "PUT"
 
 
-    def test_update_with_project(self):
-        schedule_id = 2434
-        project_id = 4
-        am = True
-        pm = True
-        comment = "this is the comment comment"
-        overwrite = True
-
-        response = self.moco.Schedule.update(schedule_id, project_id=project_id, am=am, pm=pm, comment=comment, overwrite=overwrite)
-        data = response["data"]
-
-        assert data["project_id"] == project_id
-        assert data["am"] == am
-        assert data["pm"] == pm
-        assert data["comment"] == comment
-        assert data["overwrite"] == overwrite
-
-        assert response["method"] == "PUT"
-
     def test_delete(self):
         schedule_id = 2354
 
         response = self.moco.Schedule.delete(schedule_id)
 
         assert response["method"] == "DELETE"
-        
\ No newline at end of file
